cis_config: asciiFile_t Struct Reference

cis_config

Public Attributes | List of all members
asciiFile_t Struct Reference

Structure containing information about an ASCII text file. More...

`#include <AsciiFile.h>`

## Public Attributes
const char * | filepath
| Full path to file.
char | io_mode [64]
| I/O mode. 'r' for read, 'w' for write.
char | comment [64]
| Character(s) indicating a comment.
char | newline [64]
| Character(s) indicating a newline.
FILE * | fd
| File identifier for ASCII file when open.

## Detailed Description

Structure containing information about an ASCII text file.

The documentation for this struct was generated from the following file:

- /root/cis_interface/cis_interface/cis_interface/dataio/AsciiFile.h